import { useState } from "../../common/useState";
import { useRequest } from "../../common/useRequest";
import { watch } from "vue";
import { BehaviorSubject } from "rxjs";

interface ChannelData {
  channel_id: string;
  agora_token: string;
  members: string[];
}

export function useChannelInfo() {
  const [current, setCurrent]   = useState<ChannelData>(null);
  const [channelInfo, request]  = useRequest<ChannelData>('/getAgoraToken', {}, {auto: false});
  const ready$ = new BehaviorSubject<boolean>(false);

  const createChannel = () => {
    request()
  }

  const joinCallingChannel = (id: string) => {
    request({channel_id: id})
  }

  const onReady = ( callback: () => void) => {
    ready$.subscribe( r => { r && callback() })
  }

  watch(channelInfo, val => {
    console.log('channel', val)
    setCurrent(val);
    val && ready$.next(true);
  })


  return {
    current,
    joinCallingChannel,
    createChannel,
    onReady
  }
}